@@ -1,9 +1,9 @@
 from __future__ import annotations
 
+import typing as t
 from pathlib import Path
-from typing import Iterable, Type
 
-from findpython.providers.base import BaseProvider, T
+from findpython.providers.base import BaseProvider
 from findpython.python import PythonVersion
 
 
@@ -15,12 +15,12 @@ class MacOSProvider(BaseProvider):
     INSTALL_BASE = Path("/Library/Frameworks/Python.framework/Versions/")
 
     @classmethod
-    def create(cls: Type[T]) -> T | None:
+    def create(cls) -> t.Self | None:
         if not cls.INSTALL_BASE.exists():
             return None
         return cls()
 
-    def find_pythons(self) -> Iterable[PythonVersion]:
+    def find_pythons(self) -> t.Iterable[PythonVersion]:
         for version in self.INSTALL_BASE.iterdir():
             if version.is_dir():
                 yield from self.find_pythons_from_path(version / "bin", True)
